---
name: Bug report
about: Create a report to help us improve petl
title: ''
labels: 'Bug'
assignees: ''

---

## Problem description

### What's happenning

A clear and concise description of what the bug is. Please explain:

- what the current output/behavior is
- what's the bug is preventing you from doing
- tell if it had worked before but regressed and stopped working

### Expected behavior

A clear and concise description of intended behavior. Please explain:

- what you expected to happen.
- how the current output/behavior doesn't match the intended behavior.

## Scenario for reprodution

### Reproducible test case

Please provide a minimal, reproducible code sample, a copy-pastable example if possible:

```python
# Your code here

```

### Version and installation information

Please provide the following:

- Value of ``petl.__version__``
- Version information for any third-party package dependencies that are relevant
- Version of Python interpreter
- Operating system (Linux/Windows/Mac)
- How petl was installed (e.g., "using pip into virtual environment", or "using conda")

Also, if you think it might be relevant, please provide the output from ``pip freeze`` or
``conda env export`` depending on which was used to install petl.

### Additional context

Add any other context about the problem here.

Also, feel free to remove all sections and text that aren't relevant.
